#!/bin/bash
#
# Component: cases
#
# Purpose:
#     Handles STORESCPREG released events
#
# Usage:
#    onStorescpRegReleased.sh -t <type> -e <event> -i <id>
#
#    -t type  : Object type to be released. It will always be "STORESCPREG"
#    -e event : Event triggered runiing this script. It will always be "RELASED"
#    -i id    : Identifies the objectfile object (=<Study Instance UID> + "/" + <filename>)
#
# Description:
#     Will be called when a STORESCPREG reference counter is released.
# The DICOM object will be removed from the $IMAGE_TMP directory
#
#
# ===================================================
#
# NO LONGER IN USE
#
# The actual code deleting the temporary file when the
# reference gets released has been moved to an .so
#
# backend/utils/src/libs/onStorescpRegReleased.cc
#
# ===================================================
#
#

. $HOME/etc/setenv.sh


# onStorescpRegReleased.sh can be called directly:
# run as a task instead
if [ `basename $0` = "onStorescpRegReleased.sh" ] ; then
	$TASKD_HOME/runshellcmd.sh -R -r 0 $0 "$@"
	exit $?
fi


LOGGER="/usr/bin/logger"
TAG="onStorescpRegReleased[$$]"

object=""
type=""
event=""
errMsg=""

while getopts 'e:t:i:' OPT; do
	case $OPT in
	e) event="$OPTARG" ;;
	t) type="$OPTARG" ;;
	i) object="$OPTARG" ;;
	*) errMsg="Invalid_Parameter:$OPT" ;;
	esac
done

run_()
{
	local Hash
	local Mount
	local Study
	local File

	if [ "$type" != "STORESCPREG" -o "$event" != "RELEASED" -o -z "$object" -o -n "$errMsg" ] ; then
		$LOGGER -p $LOG_FACILITY.err -t "$TAG" "Invalid argument: Type: $type; Event: $event; Objectfile: $object; $errMsg"
		return 125;
	fi

	# handles both new and old format: [[Hash_][Mount]_]Study_File
	# Hash may contain underscore and usually two char long. However we allow any length here (for the case we want to include other hash levels in the future)
	# Mount, Study and File may not contain underscore
	eval $( sed -n -E 's/^(((.*)_)?([^_]+)?_)?([^_]+)_([^_]+)$/Hash="\3";Mount="\4";Study="\5";File="\6"/p' <<< "$object" )
	if [ -n "$Hash" ] ; then
		# Current format
		fname=$REPOSITORY_DATA_DICOM/${Mount}/tmp/${Hash}/${Study}_${File}
		[ -f "$fname" ] && rm "$fname"
	elif [ -n "$Mount" ] ; then
		# Legacy tasks
		fname=$REPOSITORY_DATA_DICOM/${Mount}/tmp/${Study}_${File}
		[ -f "$fname" ] && rm "$fname"
	elif [ -z "$Study" ] ; then
		$LOGGER -p $LOG_FACILITY.err -t "$TAG" "Could not parse object file: '$object'"
		# silently fail
		return 0
	else
		# Legacy task with no mount points
		fname=$REPOSITORY_DATA_DICOM/tmp/${Study}_${File}
		if [ -f "$fname" ] ; then
			rm "$fname"
		else
			# Very old tasks
			fname="$IMAGE_TMP/${Study}/${File}"
			[ -f "$fname" ] && rm "$fname"
		fi
	fi

	return 0
}

# override print_
print_()
{
	echo "Handles Stored DICOM Object released event: Type: $type; Event: $event: Object: $object"
}



# override get_watson_message_
get_watson_message_()
{
	fname=`sed 's;/;_;' <<<"$object"`
	[ -z "$DR_WATSON_ID" ] && DR_WATSON_ID="onstorescpregreleased.$fname"
	[ -z "$DR_WATSON_MESSAGE" ] && DR_WATSON_MESSAGE="handling stored dicom object released event: $fname"

	if [ "$RUN_RESULT" -gt 124 ] ; then
		WATSON_MESSAGE_ID="$DR_WATSON_ID.failed"
		WATSON_MESSAGE_TEXT="FAILED: $DR_WATSON_MESSAGE"
		return
	fi

	if [ "$RUN_RESULT" -ne 0 -a "$RETRY_NUM" -gt 0 -a $(( $RETRY_NUM % 10)) -eq 0 ] ; then
		WATSON_MESSAGE_TEXT="ERROR: $DR_WATSON_MESSAGE [Retry #$RETRY_NUM]"
		WATSON_MESSAGE_ID="$DR_WATSON_ID.$RETRY_NUM"
	fi
} # get_watson_message_()
